Module utils

Module utils 

Structs

DebugBundle
DebugEncoder
FullComputePass
IndirectDispatcher
InspectBuffer
NormalEncoder
WorkgroupSize

Enums

AccTime
DefaultDeviceError
Dispatcher
InspectStatus

Statics

SHADER_BINDGROUP_INFER

Traits

BindingGroup

Functions

any_as_u8_slice
default_device
dispatcher_flat
For dispatching on a grid to ensure at least “len” invocations. No guarantuees are made about the layout of the workgrid. Tries to minimize invocations above “len”. The shader should calculate its own flat index to ensure consitency.
infer_compute_bindgroup_layout
inspect_texture
read_buffer
Convenience function to read a Pod type from a mappable buffer.
read_from_buffer
Same as read_buffer, but does a copy from the data buffer to the mappable buffer before mapping and reading from the mappable buffer.
read_n_from_buffer
A convenience function to read a number of items a buffer with that number being by the contents of another buffer.

Type Aliases

Encoder