Structs
Enums
Statics
Traits
Functions
- any_
as_ ⚠u8_ slice - default_
device - dispatcher_
flat - For dispatching on a grid to ensure at least “len” invocations. No guarantuees are made about the layout of the workgrid. Tries to minimize invocations above “len”. The shader should calculate its own flat index to ensure consitency.
- infer_
compute_ bindgroup_ layout - inspect_
texture - read_
buffer - Convenience function to read a Pod type from a mappable buffer.
- read_
from_ buffer - Same as read_buffer, but does a copy from the data buffer to the mappable buffer before mapping and reading from the mappable buffer.
- read_
n_ from_ buffer - A convenience function to read a number of items a buffer with that number being by the contents of another buffer.